@@ -17,7 +17,9 @@ from .utils import check_valid_name
 
 
 class ISolidDefinition(six.with_metaclass(ABCMeta)):
-    def __init__(self, name, input_defs, output_defs, description=None, metadata=None):
+    def __init__(
+        self, name, input_defs, output_defs, description=None, metadata=None, positional_inputs=None
+    ):
         self._name = check_valid_name(name)
         self._description = check.opt_str_param(description, 'description')
         self._metadata = check.opt_dict_param(metadata, 'metadata', key_type=str)
@@ -29,6 +31,12 @@ class ISolidDefinition(six.with_metaclass(ABCMeta)):
         check.invariant(
             len(self._output_defs) == len(self._output_dict), 'Duplicate output def names'
         )
+        check.opt_list_param(positional_inputs, 'positional_inputs', str)
+        self._positional_inputs = (
+            positional_inputs
+            if positional_inputs is not None
+            else list(map(lambda inp: inp.name, input_defs))
+        )
 
     @property
     def name(self):
@@ -50,6 +58,23 @@ class ISolidDefinition(six.with_metaclass(ABCMeta)):
     def input_dict(self):
         return self._input_dict
 
+    def resolve_input_name_at_position(self, idx):
+        if idx >= len(self._positional_inputs):
+            if not (
+                len(self._input_defs) - len(self._positional_inputs) == 1
+                and idx == len(self._input_defs) - 1
+            ):
+                return None
+
+            # handle special case where there is only 1 non-positional arg that we could resolve to
+            names = [
+                inp.name for inp in self._input_defs if inp.name not in self._positional_inputs
+            ]
+            check.invariant(len(names) == 1, 'if check above should prevent this')
+            return names[0]
+
+        return self._positional_inputs[idx]
+
     @property
     def output_defs(self):
         return self._output_defs
@@ -145,6 +170,9 @@ class SolidDefinition(ISolidDefinition):
             expect and require certain metadata to be attached to a solid.
         required_resource_keys (Optional[Set[str]]): Set of resources handles required by this
             solid.
+        positional_inputs (Optional[List[str]]): The positional order of the input names if it
+            differs from the order of the input definitions.
+
 
     Examples:
         .. code-block:: python
@@ -171,6 +199,7 @@ class SolidDefinition(ISolidDefinition):
         metadata=None,
         required_resource_keys=None,
         step_metadata_fn=None,
+        positional_inputs=None,
     ):
         self._compute_fn = check.callable_param(compute_fn, 'compute_fn')
         self._config_field = check_user_facing_opt_field_param(
@@ -189,6 +218,7 @@ class SolidDefinition(ISolidDefinition):
             output_defs=check.list_param(output_defs, 'output_defs', OutputDefinition),
             description=description,
             metadata=metadata,
+            positional_inputs=positional_inputs,
         )
 
     @property
@@ -251,6 +281,8 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
         description (Optional[str]): Human readable description of this composite solid.
         metadata (Optional[Dict[Any, Any]]): Arbitrary metadata for the composite solid. Frameworks
             may expect and require certain metadata to be attached to a solid.
+        positional_inputs (Optional[List[str]]): The positional order of the inputs if it
+            differs from the order of the input mappings
 
     Examples:
 
@@ -282,6 +314,7 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
         dependencies=None,
         description=None,
         metadata=None,
+        positional_inputs=None,
     ):
         check.str_param(name, 'name')
         self._solid_defs = check.list_param(solid_defs, 'solid_defs', of_type=ISolidDefinition)
@@ -312,6 +345,7 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
             output_defs=output_defs,
             description=description,
             metadata=metadata,
+            positional_inputs=positional_inputs,
         )
 
     @property
