@@ -1,10 +1,10 @@
 import glob
+import logging
 import os
 import sqlite3
 from collections import defaultdict
 from contextlib import contextmanager
 
-import six
 import sqlalchemy as db
 from sqlalchemy.pool import NullPool
 from watchdog.events import PatternMatchingEventHandler
@@ -24,7 +24,6 @@ from ...sql import (
     run_alembic_upgrade,
     stamp_alembic_rev,
 )
-from ..base import DagsterEventLogInvalidForRun
 from ..schema import SqlEventLogStorageMetadata
 from ..sql_event_log import SqlEventLogStorage
 
@@ -77,18 +76,29 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         return 'sqlite:///{}'.format('/'.join(self.path_for_run_id(run_id).split(os.sep)))
 
     def _initdb(self, engine, run_id):
+
+        alembic_config = get_alembic_config(__file__)
+
         try:
             SqlEventLogStorageMetadata.create_all(engine)
             engine.execute('PRAGMA journal_mode=WAL;')
-        except (db.exc.DatabaseError, sqlite3.DatabaseError) as exc:
-            six.raise_from(DagsterEventLogInvalidForRun(run_id=run_id), exc)
-
-        alembic_config = get_alembic_config(__file__)
-        conn = engine.connect()
-        try:
-            stamp_alembic_rev(alembic_config, conn)
-        finally:
-            conn.close()
+            stamp_alembic_rev(alembic_config, engine)
+        except (db.exc.DatabaseError, sqlite3.DatabaseError, sqlite3.OperationalError) as exc:
+            # This is SQLite-specific handling for concurrency issues that can arise when, e.g.,
+            # the root nodes of a pipeline execute simultaneously on Airflow with SQLite storage
+            # configured and contend with each other to init the db. When we hit the following
+            # errors, we know that another process is on the case and it's safe to continue:
+            if not (
+                'table event_logs already exists' in str(exc)
+                or 'database is locked' in str(exc)
+                or 'table alembic_version already exists' in str(exc)
+            ):
+                raise
+            else:
+                logging.info(
+                    'SqliteEventLogStorage._initdb: Encountered apparent concurrent init, '
+                    'swallowing {str_exc}'.format(str_exc=str(exc))
+                )
 
     @contextmanager
     def connect(self, run_id=None):
@@ -110,6 +120,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                 yield conn
         finally:
             conn.close()
+        engine.dispose()
 
     def wipe(self):
         for filename in (
@@ -153,10 +164,6 @@ class SqliteEventLogStorageWatchdog(PatternMatchingEventHandler):
             if status == PipelineRunStatus.SUCCESS or status == PipelineRunStatus.FAILURE:
                 self._event_log_storage.end_watch(self._run_id, self._cb)
 
-    def on_created(self, event):
-        check.invariant(event.src_path == self._log_path)
-        self._process_log()
-
     def on_modified(self, event):
         check.invariant(event.src_path == self._log_path)
         self._process_log()
