@@ -7,9 +7,8 @@ from dagster.core.serdes import whitelist_for_serdes
 @whitelist_for_serdes
 class SerializableErrorInfo(namedtuple('SerializableErrorInfo', 'message stack cls_name')):
     def to_string(self):
-        return '({err.cls_name}) - {err.message}\nStack Trace: \n{stack}'.format(
-            err=self, stack=''.join(self.stack)
-        )
+        stack_str = '\nStack Trace: \n' + ''.join(self.stack) if self.stack else ''
+        return '({err.cls_name}) - {err.message}{stack}'.format(err=self, stack=stack_str)
 
 
 def serializable_error_info_from_exc_info(exc_info):
